@@ -18,18 +18,18 @@ from typing import Any, Dict, List, Type
 from botocore.client import ClientMeta
 
 from .literals import (
-    AccountScope,
-    AnomalyFeedbackType,
-    AnomalySubscriptionFrequency,
-    Context,
-    Dimension,
-    Granularity,
-    LookbackPeriodInDays,
-    Metric,
-    PaymentOption,
-    SavingsPlansDataType,
-    SupportedSavingsPlansType,
-    TermInYears,
+    AccountScopeType,
+    AnomalyFeedbackTypeType,
+    AnomalySubscriptionFrequencyType,
+    ContextType,
+    DimensionType,
+    GranularityType,
+    LookbackPeriodInDaysType,
+    MetricType,
+    PaymentOptionType,
+    SavingsPlansDataTypeType,
+    SupportedSavingsPlansTypeType,
+    TermInYearsType,
 )
 from .type_defs import (
     AnomalyDateIntervalTypeDef,
@@ -107,7 +107,7 @@ class Exceptions:
 
 class CostExplorerClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -116,24 +116,24 @@ class CostExplorerClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def create_anomaly_monitor(
         self, AnomalyMonitor: "AnomalyMonitorTypeDef"
     ) -> CreateAnomalyMonitorResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.create_anomaly_monitor)
-        [Show boto3-stubs documentation](./client.md#create-anomaly-monitor)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.create_anomaly_monitor)
+        [Show boto3-stubs documentation](./client.md#create_anomaly_monitor)
         """
 
     def create_anomaly_subscription(
         self, AnomalySubscription: "AnomalySubscriptionTypeDef"
     ) -> CreateAnomalySubscriptionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.create_anomaly_subscription)
-        [Show boto3-stubs documentation](./client.md#create-anomaly-subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.create_anomaly_subscription)
+        [Show boto3-stubs documentation](./client.md#create_anomaly_subscription)
         """
 
     def create_cost_category_definition(
@@ -144,36 +144,36 @@ class CostExplorerClient:
         DefaultValue: str = None,
     ) -> CreateCostCategoryDefinitionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.create_cost_category_definition)
-        [Show boto3-stubs documentation](./client.md#create-cost-category-definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.create_cost_category_definition)
+        [Show boto3-stubs documentation](./client.md#create_cost_category_definition)
         """
 
     def delete_anomaly_monitor(self, MonitorArn: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.delete_anomaly_monitor)
-        [Show boto3-stubs documentation](./client.md#delete-anomaly-monitor)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.delete_anomaly_monitor)
+        [Show boto3-stubs documentation](./client.md#delete_anomaly_monitor)
         """
 
     def delete_anomaly_subscription(self, SubscriptionArn: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.delete_anomaly_subscription)
-        [Show boto3-stubs documentation](./client.md#delete-anomaly-subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.delete_anomaly_subscription)
+        [Show boto3-stubs documentation](./client.md#delete_anomaly_subscription)
         """
 
     def delete_cost_category_definition(
         self, CostCategoryArn: str
     ) -> DeleteCostCategoryDefinitionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.delete_cost_category_definition)
-        [Show boto3-stubs documentation](./client.md#delete-cost-category-definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.delete_cost_category_definition)
+        [Show boto3-stubs documentation](./client.md#delete_cost_category_definition)
         """
 
     def describe_cost_category_definition(
         self, CostCategoryArn: str, EffectiveOn: str = None
     ) -> DescribeCostCategoryDefinitionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.describe_cost_category_definition)
-        [Show boto3-stubs documentation](./client.md#describe-cost-category-definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.describe_cost_category_definition)
+        [Show boto3-stubs documentation](./client.md#describe_cost_category_definition)
         """
 
     def generate_presigned_url(
@@ -184,30 +184,30 @@ class CostExplorerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def get_anomalies(
         self,
         DateInterval: AnomalyDateIntervalTypeDef,
         MonitorArn: str = None,
-        Feedback: AnomalyFeedbackType = None,
+        Feedback: AnomalyFeedbackTypeType = None,
         TotalImpact: TotalImpactFilterTypeDef = None,
         NextPageToken: str = None,
         MaxResults: int = None,
     ) -> GetAnomaliesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.get_anomalies)
-        [Show boto3-stubs documentation](./client.md#get-anomalies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.get_anomalies)
+        [Show boto3-stubs documentation](./client.md#get_anomalies)
         """
 
     def get_anomaly_monitors(
         self, MonitorArnList: List[str] = None, NextPageToken: str = None, MaxResults: int = None
     ) -> GetAnomalyMonitorsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.get_anomaly_monitors)
-        [Show boto3-stubs documentation](./client.md#get-anomaly-monitors)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.get_anomaly_monitors)
+        [Show boto3-stubs documentation](./client.md#get_anomaly_monitors)
         """
 
     def get_anomaly_subscriptions(
@@ -218,36 +218,36 @@ class CostExplorerClient:
         MaxResults: int = None,
     ) -> GetAnomalySubscriptionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.get_anomaly_subscriptions)
-        [Show boto3-stubs documentation](./client.md#get-anomaly-subscriptions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.get_anomaly_subscriptions)
+        [Show boto3-stubs documentation](./client.md#get_anomaly_subscriptions)
         """
 
     def get_cost_and_usage(
         self,
         TimePeriod: "DateIntervalTypeDef",
-        Granularity: Granularity,
+        Granularity: GranularityType,
         Metrics: List[str],
         Filter: "ExpressionTypeDef" = None,
         GroupBy: List["GroupDefinitionTypeDef"] = None,
         NextPageToken: str = None,
     ) -> GetCostAndUsageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage)
-        [Show boto3-stubs documentation](./client.md#get-cost-and-usage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage)
+        [Show boto3-stubs documentation](./client.md#get_cost_and_usage)
         """
 
     def get_cost_and_usage_with_resources(
         self,
         TimePeriod: "DateIntervalTypeDef",
-        Granularity: Granularity,
+        Granularity: GranularityType,
         Filter: "ExpressionTypeDef",
         Metrics: List[str] = None,
         GroupBy: List["GroupDefinitionTypeDef"] = None,
         NextPageToken: str = None,
     ) -> GetCostAndUsageWithResourcesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage_with_resources)
-        [Show boto3-stubs documentation](./client.md#get-cost-and-usage-with-resources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.get_cost_and_usage_with_resources)
+        [Show boto3-stubs documentation](./client.md#get_cost_and_usage_with_resources)
         """
 
     def get_cost_categories(
@@ -261,44 +261,44 @@ class CostExplorerClient:
         NextPageToken: str = None,
     ) -> GetCostCategoriesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.get_cost_categories)
-        [Show boto3-stubs documentation](./client.md#get-cost-categories)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.get_cost_categories)
+        [Show boto3-stubs documentation](./client.md#get_cost_categories)
         """
 
     def get_cost_forecast(
         self,
         TimePeriod: "DateIntervalTypeDef",
-        Metric: Metric,
-        Granularity: Granularity,
+        Metric: MetricType,
+        Granularity: GranularityType,
         Filter: "ExpressionTypeDef" = None,
         PredictionIntervalLevel: int = None,
     ) -> GetCostForecastResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.get_cost_forecast)
-        [Show boto3-stubs documentation](./client.md#get-cost-forecast)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.get_cost_forecast)
+        [Show boto3-stubs documentation](./client.md#get_cost_forecast)
         """
 
     def get_dimension_values(
         self,
         TimePeriod: "DateIntervalTypeDef",
-        Dimension: Dimension,
+        Dimension: DimensionType,
         SearchString: str = None,
-        Context: Context = None,
+        Context: ContextType = None,
         Filter: "ExpressionTypeDef" = None,
         SortBy: List[SortDefinitionTypeDef] = None,
         MaxResults: int = None,
         NextPageToken: str = None,
     ) -> GetDimensionValuesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.get_dimension_values)
-        [Show boto3-stubs documentation](./client.md#get-dimension-values)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.get_dimension_values)
+        [Show boto3-stubs documentation](./client.md#get_dimension_values)
         """
 
     def get_reservation_coverage(
         self,
         TimePeriod: "DateIntervalTypeDef",
         GroupBy: List["GroupDefinitionTypeDef"] = None,
-        Granularity: Granularity = None,
+        Granularity: GranularityType = None,
         Filter: "ExpressionTypeDef" = None,
         Metrics: List[str] = None,
         NextPageToken: str = None,
@@ -306,8 +306,8 @@ class CostExplorerClient:
         MaxResults: int = None,
     ) -> GetReservationCoverageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.get_reservation_coverage)
-        [Show boto3-stubs documentation](./client.md#get-reservation-coverage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.get_reservation_coverage)
+        [Show boto3-stubs documentation](./client.md#get_reservation_coverage)
         """
 
     def get_reservation_purchase_recommendation(
@@ -315,32 +315,32 @@ class CostExplorerClient:
         Service: str,
         AccountId: str = None,
         Filter: "ExpressionTypeDef" = None,
-        AccountScope: AccountScope = None,
-        LookbackPeriodInDays: LookbackPeriodInDays = None,
-        TermInYears: TermInYears = None,
-        PaymentOption: PaymentOption = None,
+        AccountScope: AccountScopeType = None,
+        LookbackPeriodInDays: LookbackPeriodInDaysType = None,
+        TermInYears: TermInYearsType = None,
+        PaymentOption: PaymentOptionType = None,
         ServiceSpecification: "ServiceSpecificationTypeDef" = None,
         PageSize: int = None,
         NextPageToken: str = None,
     ) -> GetReservationPurchaseRecommendationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.get_reservation_purchase_recommendation)
-        [Show boto3-stubs documentation](./client.md#get-reservation-purchase-recommendation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.get_reservation_purchase_recommendation)
+        [Show boto3-stubs documentation](./client.md#get_reservation_purchase_recommendation)
         """
 
     def get_reservation_utilization(
         self,
         TimePeriod: "DateIntervalTypeDef",
         GroupBy: List["GroupDefinitionTypeDef"] = None,
-        Granularity: Granularity = None,
+        Granularity: GranularityType = None,
         Filter: "ExpressionTypeDef" = None,
         SortBy: SortDefinitionTypeDef = None,
         NextPageToken: str = None,
         MaxResults: int = None,
     ) -> GetReservationUtilizationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.get_reservation_utilization)
-        [Show boto3-stubs documentation](./client.md#get-reservation-utilization)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.get_reservation_utilization)
+        [Show boto3-stubs documentation](./client.md#get_reservation_utilization)
         """
 
     def get_rightsizing_recommendation(
@@ -352,15 +352,15 @@ class CostExplorerClient:
         NextPageToken: str = None,
     ) -> GetRightsizingRecommendationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.get_rightsizing_recommendation)
-        [Show boto3-stubs documentation](./client.md#get-rightsizing-recommendation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.get_rightsizing_recommendation)
+        [Show boto3-stubs documentation](./client.md#get_rightsizing_recommendation)
         """
 
     def get_savings_plans_coverage(
         self,
         TimePeriod: "DateIntervalTypeDef",
         GroupBy: List["GroupDefinitionTypeDef"] = None,
-        Granularity: Granularity = None,
+        Granularity: GranularityType = None,
         Filter: "ExpressionTypeDef" = None,
         Metrics: List[str] = None,
         NextToken: str = None,
@@ -368,50 +368,50 @@ class CostExplorerClient:
         SortBy: SortDefinitionTypeDef = None,
     ) -> GetSavingsPlansCoverageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.get_savings_plans_coverage)
-        [Show boto3-stubs documentation](./client.md#get-savings-plans-coverage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.get_savings_plans_coverage)
+        [Show boto3-stubs documentation](./client.md#get_savings_plans_coverage)
         """
 
     def get_savings_plans_purchase_recommendation(
         self,
-        SavingsPlansType: SupportedSavingsPlansType,
-        TermInYears: TermInYears,
-        PaymentOption: PaymentOption,
-        LookbackPeriodInDays: LookbackPeriodInDays,
-        AccountScope: AccountScope = None,
+        SavingsPlansType: SupportedSavingsPlansTypeType,
+        TermInYears: TermInYearsType,
+        PaymentOption: PaymentOptionType,
+        LookbackPeriodInDays: LookbackPeriodInDaysType,
+        AccountScope: AccountScopeType = None,
         NextPageToken: str = None,
         PageSize: int = None,
         Filter: "ExpressionTypeDef" = None,
     ) -> GetSavingsPlansPurchaseRecommendationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.get_savings_plans_purchase_recommendation)
-        [Show boto3-stubs documentation](./client.md#get-savings-plans-purchase-recommendation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.get_savings_plans_purchase_recommendation)
+        [Show boto3-stubs documentation](./client.md#get_savings_plans_purchase_recommendation)
         """
 
     def get_savings_plans_utilization(
         self,
         TimePeriod: "DateIntervalTypeDef",
-        Granularity: Granularity = None,
+        Granularity: GranularityType = None,
         Filter: "ExpressionTypeDef" = None,
         SortBy: SortDefinitionTypeDef = None,
     ) -> GetSavingsPlansUtilizationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization)
-        [Show boto3-stubs documentation](./client.md#get-savings-plans-utilization)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization)
+        [Show boto3-stubs documentation](./client.md#get_savings_plans_utilization)
         """
 
     def get_savings_plans_utilization_details(
         self,
         TimePeriod: "DateIntervalTypeDef",
         Filter: "ExpressionTypeDef" = None,
-        DataType: List[SavingsPlansDataType] = None,
+        DataType: List[SavingsPlansDataTypeType] = None,
         NextToken: str = None,
         MaxResults: int = None,
         SortBy: SortDefinitionTypeDef = None,
     ) -> GetSavingsPlansUtilizationDetailsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization_details)
-        [Show boto3-stubs documentation](./client.md#get-savings-plans-utilization-details)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.get_savings_plans_utilization_details)
+        [Show boto3-stubs documentation](./client.md#get_savings_plans_utilization_details)
         """
 
     def get_tags(
@@ -425,59 +425,59 @@ class CostExplorerClient:
         NextPageToken: str = None,
     ) -> GetTagsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.get_tags)
-        [Show boto3-stubs documentation](./client.md#get-tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.get_tags)
+        [Show boto3-stubs documentation](./client.md#get_tags)
         """
 
     def get_usage_forecast(
         self,
         TimePeriod: "DateIntervalTypeDef",
-        Metric: Metric,
-        Granularity: Granularity,
+        Metric: MetricType,
+        Granularity: GranularityType,
         Filter: "ExpressionTypeDef" = None,
         PredictionIntervalLevel: int = None,
     ) -> GetUsageForecastResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.get_usage_forecast)
-        [Show boto3-stubs documentation](./client.md#get-usage-forecast)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.get_usage_forecast)
+        [Show boto3-stubs documentation](./client.md#get_usage_forecast)
         """
 
     def list_cost_category_definitions(
         self, EffectiveOn: str = None, NextToken: str = None, MaxResults: int = None
     ) -> ListCostCategoryDefinitionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.list_cost_category_definitions)
-        [Show boto3-stubs documentation](./client.md#list-cost-category-definitions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.list_cost_category_definitions)
+        [Show boto3-stubs documentation](./client.md#list_cost_category_definitions)
         """
 
     def provide_anomaly_feedback(
-        self, AnomalyId: str, Feedback: AnomalyFeedbackType
+        self, AnomalyId: str, Feedback: AnomalyFeedbackTypeType
     ) -> ProvideAnomalyFeedbackResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.provide_anomaly_feedback)
-        [Show boto3-stubs documentation](./client.md#provide-anomaly-feedback)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.provide_anomaly_feedback)
+        [Show boto3-stubs documentation](./client.md#provide_anomaly_feedback)
         """
 
     def update_anomaly_monitor(
         self, MonitorArn: str, MonitorName: str = None
     ) -> UpdateAnomalyMonitorResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.update_anomaly_monitor)
-        [Show boto3-stubs documentation](./client.md#update-anomaly-monitor)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.update_anomaly_monitor)
+        [Show boto3-stubs documentation](./client.md#update_anomaly_monitor)
         """
 
     def update_anomaly_subscription(
         self,
         SubscriptionArn: str,
         Threshold: float = None,
-        Frequency: AnomalySubscriptionFrequency = None,
+        Frequency: AnomalySubscriptionFrequencyType = None,
         MonitorArnList: List[str] = None,
         Subscribers: List["SubscriberTypeDef"] = None,
         SubscriptionName: str = None,
     ) -> UpdateAnomalySubscriptionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.update_anomaly_subscription)
-        [Show boto3-stubs documentation](./client.md#update-anomaly-subscription)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.update_anomaly_subscription)
+        [Show boto3-stubs documentation](./client.md#update_anomaly_subscription)
         """
 
     def update_cost_category_definition(
@@ -488,6 +488,6 @@ class CostExplorerClient:
         DefaultValue: str = None,
     ) -> UpdateCostCategoryDefinitionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/ce.html#CostExplorer.Client.update_cost_category_definition)
-        [Show boto3-stubs documentation](./client.md#update-cost-category-definition)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/ce.html#CostExplorer.Client.update_cost_category_definition)
+        [Show boto3-stubs documentation](./client.md#update_cost_category_definition)
         """
